Security Advisories (3)
CVE-2007-6341 (2008-02-08)

Allows remote attackers to cause a denial of service (program "croak") via a crafted DNS response.

CVE-2007-3409 (2007-06-26)

Net::DNS before 0.60, a Perl module, allows remote attackers to cause a denial of service (stack consumption) via a malformed compressed DNS packet with self-referencing pointers, which triggers an infinite loop.

CVE-2007-3377 (2007-06-25)

Header.pm in Net::DNS before 0.60, a Perl module, (1) generates predictable sequence IDs with a fixed increment and (2) can use the same starting ID for all child processes of a forking server, which allows remote attackers to spoof DNS responses, as originally reported for qpsmtp and spamassassin.

NAME

DNSHash::MX - Put DNS MX queries in a hash lookup format

SYNOPSIS

require DNSHash;

tie %DNS, "DNSHash::MX", <preload>, <cachedb>, <usettl>

$mxhostname = $DNS{"host.do.main"};

DESCRIPTION

This implements DNS MX lookups as a tied hash. It takes the first answer at the lowest priority (like sendmail would to).

If the file <preload> is defined, the hash is preloaded with the hostname/mxhostname pairs found in this file. Format is

mxhostname   hostname

Assignments to this hash are added to the preload lookup. You can delete preload lookups by delete()ing the entry.

Lookups are cached once done if <cachedb> is defined.

Cache entries are held for <usettl> seconds unless <usettl> undefined, in which case the TTL of the record is used in each case.

You can clear the cache by removing <cachedb>. If you want to clear a particular lookup in the cache, use delete().

each() on these hashes only walks the preload.

NAME

DNSHash - Put DNS hostname/ip queries in a hash lookup format

SYNOPSIS

require DNSHash;

tie %DNS, "DNSHash", <preload>, <cachedb>, <usettl>

$hostname = $DNS{"a.b.c.d"}; $ip = $DNS{"host.do.main"};

$DNS{"host.do.main"} = $realip;

DESCRIPTION

This implements DNS A and PTR record lookup as a tied hash.

If the file <preload> is defined, the hash is preloaded with the hostname/ip pairs found in the file (format is like /etc/hosts).

Assignments to this hash are added to the preload lookup. You can delete preload lookups by delete()ing the entry.

Lookups are cached once done if <cachedb> is defined.

Cache entries are held for <usettl> seconds unless <usettl> undefined, in which case the TTL of the record is used in each case.

You can clear the cache by removing <cachedb>. If you want to clear a particular lookup in the cache, use delete().

each() on these hashes only walks the preload.